Comments

nitely Esteban Castro Borsani

- 3
- 4h

Which one will you take?

- Red pill
- Blue pill

Closes on Mar 2, 12hs. You may select 1 choice.
Show results close

message

- report
- like
- reply

nitely Esteban Castro Borsani

- 3
- 4h

Which one will you take?

- Red pill, 75%
- Blue pill, 25%

Votes: 120.
Show vote choices close

message

- report
- like
- reply

nitely Esteban Castro Borsani

- 3
- 4h

Which one will you take?

- Red pill
- Blue pill

You must select 2 choices.
Show results close

message

Which one will you take?

- Red pill
- Blue pill

You may select 4 choices and no less than 2.
Show results close
Which one will you take?

- Red pill
- Blue pill

Show results close

- report
- like
- reply

nitely Esteban Castro Borsani

- 4h

Which one will you take?

- #1 Red pill
- #2 Blue pill

Name: 1, minimum selection: 1, maximum selection: 1, mode: default

This is a static poll (comment history)